@@ -24,6 +24,7 @@
 	2014.02.14 V00.18 Changed Hole Punching packet format
 	2014.02.16 V00.19 Bug fixed for CallCheck
 	2014.02.17 V00.20 Added DPRS Switch & DPRS STRIP
+		   V00.21 Added SO_REUSEADDR for each socket
 */
 
 #include	"dsgwd_pi.h"
@@ -301,6 +302,7 @@ int main(int argc, const char **argv)
 	FILE	*PidFile;
 	int	cmdin;
 	int	KeepAliveCnt;
+	int	opt;
 
         signal(SIGINT,CloseSocket);
         signal(SIGTERM,CloseSocket);
@@ -417,6 +419,24 @@ int main(int argc, const char **argv)
 	dstSocket = socket(PF_INET, SOCK_STREAM, 0);
 	udpSocket = socket(PF_INET, SOCK_DGRAM, 0);
 
+        opt = 1;
+        if (setsockopt(dstSocket, SOL_SOCKET, SO_REUSEADDR, &opt, sizeof(int)) != 0){
+		logfile = fopen (LOGFILE, "a");
+		now = time(NULL);
+		fprintf (logfile, "%24.24s SO_REUSEADDR(dstSocket) ERROR\n");
+		fclose (logfile);
+                exit(-1);
+        }
+
+        opt = 1;
+        if (setsockopt(udpSocket, SOL_SOCKET, SO_REUSEADDR, &opt, sizeof(int)) != 0){
+                logfile = fopen (LOGFILE, "a");
+                now = time(NULL);
+                fprintf (logfile, "%24.24s SO_REUSEADDR(udpSocket) ERROR\n");
+                fclose (logfile);
+                exit(-1);
+        }
+
 	//接続
 	if (connect(dstSocket, (struct sockaddr *)&dstAddr, 
 			sizeof(dstAddr)) < 0){
