@@ -31,7 +31,7 @@ void	from_inet(void)
 	{
 		if (q_pkt.B_header.seq == 0x80)
 		{
-			send_header_USB((char*)&q_pkt.header);
+			send_header_USB(q_pkt.header);
 		}
 		else if (q_pkt.B_header.seq & 0x1f)
 		{
@@ -45,16 +45,18 @@ void	from_inet(void)
 	if (VoicePacketSW && (JitterBufferPnt != CurJitterBufferPnt)) JitterBufferSend();
 }
 
-void	send_header_USB(char pkt[])
+void	send_header_USB(struct header pkt)
 {
 	if (JitterBufferPnt != CurJitterBufferPnt) JitterBufferSend();
 
-	usb_control_msg(udev, 0x40, SET_MyCALL2, 0, 0, &pkt[35], 4, 100);
-	usb_control_msg(udev, 0x40, SET_MyCALL, 0, 0, &pkt[27], 8, 100);
-	usb_control_msg(udev, 0x40, SET_YourCALL, 0, 0, &pkt[19], 8, 100);
-	usb_control_msg(udev, 0x40, SET_RPT1CALL, 0, 0, &pkt[11], 8, 100);
-	usb_control_msg(udev, 0x40, SET_RPT2CALL, 0, 0, &pkt[3], 8, 100);
-   	usb_control_msg(udev, 0x40, SET_FLAGS, 0, 0, &pkt[0], 3, 100);
+	if (memcmp (&pkt.YourCall, &client_call, 8) == 0) memcpy (&pkt.YourCall, "CQCQCQ  ", 8);
+	if (pkt.YourCall[0] == '/') memcpy (&pkt.YourCall, "CQCQCQ  ", 8);
+	usb_control_msg(udev, 0x40, SET_MyCALL2, 0, 0, &pkt.MyCall2, 4, 100);
+	usb_control_msg(udev, 0x40, SET_MyCALL, 0, 0, &pkt.MyCall, 8, 100);
+	usb_control_msg(udev, 0x40, SET_YourCALL, 0, 0, &pkt.YourCall, 8, 100);
+	usb_control_msg(udev, 0x40, SET_RPT1CALL, 0, 0, &pkt.Rpt1Call, 8, 100);
+	usb_control_msg(udev, 0x40, SET_RPT2CALL, 0, 0, &pkt.Rpt2Call, 8, 100);
+   	usb_control_msg(udev, 0x40, SET_FLAGS, 0, 0, &pkt.flags, 3, 100);
 
 	JitterBufferPnt = 0;
 	CurJitterBufferPnt = 0;
