@@ -207,13 +207,16 @@ void	send_voice_queue(void) 	/* read from rig (DV packet) */
 				DprsStripSW = TRUE;
 			}
 		}
-	}
-	if (DprsStripSW)
-	{
-		DprsStripSW = FALSE;
-		dv_frame.voice.slowdata[0] = 0x66 ^ 0x70;
-		dv_frame.voice.slowdata[1] = 0x66 ^ 0x4f;
-		dv_frame.voice.slowdata[2] = 0x66 ^ 0x93;
+		else
+		{
+			if (DprsStripSW)
+			{
+				DprsStripSW = FALSE;
+				dv_frame.voice.slowdata[0] = 0x66 ^ 0x70;
+				dv_frame.voice.slowdata[1] = 0x66 ^ 0x4f;
+				dv_frame.voice.slowdata[2] = 0x66 ^ 0x93;
+			}
+		}
 	}
 	if (SendToInet) mq_send (rf_qid, (char *)&dv_frame, sizeof(dv_frame), 1);
 	if (repeater_mode)
